#region Copyright (C) 2005-2011 Team MediaPortal

// Copyright (C) 2005-2011 Team MediaPortal
// http://www.team-mediaportal.com
// 
// MediaPortal is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 2 of the License, or
// (at your option) any later version.
// 
// MediaPortal is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with MediaPortal. If not, see <http://www.gnu.org/licenses/>.

#endregion

using System;
using System.Diagnostics;
using System.IO;
using TvLibrary.Log;
using TvControl;
using SetupTv;
using TvEngine.Events;
using TvLibrary.Interfaces;
using TvLibrary.Implementations;
using TvDatabase;

using System.Net;
using System.Windows.Forms;

namespace TvEngine
{
    public class DirecTV_SHEF : AnalogChannel, ITvServerPlugin
  {

    #region Members

    private static string _receiverAddress = "";

    #endregion Members

    #region Properties

    /// <summary>
    /// returns the name of the plugin
    /// </summary>
    public new string Name
    {
      get { return "DirecTV SHEF"; }
    }

    /// <summary>
    /// returns the version of the plugin
    /// </summary>
    public string Version
    {
      get { return "1.0.1.0"; }
    }

    /// <summary>
    /// returns the author of the plugin
    /// </summary>
    public string Author
    {
      get { return "marirs"; }
    }

    /// <summary>
    /// returns if the plugin should only run on the master server
    /// or also on slave servers
    /// </summary>
    public bool MasterOnly
    {
      get { return false; }
    }

    internal static string ReceiverAddress
    {
        get { return _receiverAddress; }
        set { _receiverAddress = value; }
    }

    #endregion Properties

    #region IPlugin Members

//    [CLSCompliant(false)]
    public void Start(IController controller)
    {
      Log.Info("plugin: DirecTV SHEF start");
      LoadSettings();
      GlobalServiceProvider.Instance.Get<ITvServerEvent>().OnTvServerEvent += DirecTV_SHEF_OnTvServerEvent;
    }

    public void Stop()
    {
      Log.Info("plugin: DirecTV SHEF stop");
      if (GlobalServiceProvider.Instance.IsRegistered<ITvServerEvent>())
      {
        GlobalServiceProvider.Instance.Get<ITvServerEvent>().OnTvServerEvent -= DirecTV_SHEF_OnTvServerEvent;
      }
    }

//    [CLSCompliant(false)]
    public SectionSettings Setup
    {
      get { return new SetupTv.Sections.DirecTV_SHEFSetup(); }
    }

    #endregion

    #region Implementation

    private static void SendDTVCommand(string cmd)
    {
      string url = "http://" + _receiverAddress + ":8080/" + cmd;
      HttpWebRequest req = (HttpWebRequest)HttpWebRequest.Create(url);
      StreamReader reader = new StreamReader(req.GetResponse().GetResponseStream());
      reader.ReadToEnd();
    }

    private static void DirecTV_SHEF_OnTvServerEvent(object sender, EventArgs eventArgs)
    {
      try
      {
        TvServerEventArgs tvEvent = (TvServerEventArgs)eventArgs;
        AnalogChannel analogChannel = tvEvent.channel as AnalogChannel;
        if (analogChannel == null) return;

        // Change channel
        if (tvEvent.EventType == TvServerEventType.StartZapChannel)
        {
          Log.Debug("DirecTV SHEF - Channel change for CardId: {0}, Channel: {1} - Channel:{2} - VideoSource: {3}",
                    tvEvent.Card.Id, analogChannel.ChannelNumber, analogChannel.Name,
                    analogChannel.VideoSource.ToString());
          SendDTVCommand("remote/processKey?key=poweron");
          SendDTVCommand("tv/tune?major=" + analogChannel.ChannelNumber.ToString() + "&minor=65535");
        }

        // Start TV
        if (tvEvent.EventType == TvServerEventType.StartTimeShifting)
        {
          Log.Debug("DirecTV SHEF - Start time shifting for CardId: {0}, Channel: {1} - Channel:{2} - VideoSource: {3}",
                   tvEvent.Card.Id, analogChannel.ChannelNumber, analogChannel.Name,
                   analogChannel.VideoSource.ToString());
          SendDTVCommand("remote/processKey?key=poweron");
        }

        // Stop TV
        if (tvEvent.EventType == TvServerEventType.EndTimeShifting)
        {
          Log.Debug("DirecTV SHEF - End time shifting for CardId: {0}, Channel: {1} - Channel:{2} - VideoSource: {3}",
                    tvEvent.Card.Id, analogChannel.ChannelNumber, analogChannel.Name,
                    analogChannel.VideoSource.ToString());
          SendDTVCommand("remote/processKey?key=poweroff");
        }
      }
      catch (Exception ex)
      {
        Log.Error("DirecTV SHEF - DirecTV_SHEF_OnTvServerEvent(): {0}", ex.Message);
      }
    }

    internal static void LoadSettings()
    {
      try
      {
        TvBusinessLayer layer = new TvBusinessLayer();
        _receiverAddress = layer.GetSetting("DirecTV_SHEF_ReceiverAddress").Value;
      }
      catch (Exception ex)
      {
        Log.Error("DirecTV SHEF - LoadSettings(): {0}", ex.Message);
      }
    }

    internal static void SaveSettings()
    {
      try
      {
        TvBusinessLayer layer = new TvBusinessLayer();

        Setting setting = layer.GetSetting("DirecTV_SHEF_ReceiverAddress");
        setting.Value = _receiverAddress;
        setting.Persist();
      }
      catch (Exception ex)
      {
        Log.Error("DirecTV SHEF - SaveSettings(): {0}", ex.Message);
      }
    }
    #endregion Implementation

  }
}