#region Copyright (C) 2005-2011 Team MediaPortal

// Copyright (C) 2005-2011 Team MediaPortal
// http://www.team-mediaportal.com
// 
// MediaPortal is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 2 of the License, or
// (at your option) any later version.
// 
// MediaPortal is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with MediaPortal. If not, see <http://www.gnu.org/licenses/>.

#endregion

using System;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Drawing;
using System.IO;
using System.Text;
using System.Windows.Forms;
using TvLibrary.Log;
using TvEngine;
using TvControl;
using TvDatabase;

using System.Net;

namespace SetupTv.Sections
{
  [CLSCompliant(false)]
  public partial class DirecTV_SHEFSetup : SetupTv.SectionSettings
  {
    #region Properties

    public string ReceiverAddress
    {
      get { return tbAddress.Text; }
      set { tbAddress.Text = value; }
    }

    #endregion Properties

    #region Constructor

    public DirecTV_SHEFSetup()
    {
      InitializeComponent();
    }

    #endregion Constructor

    #region SetupTv.SectionSettings

    public override void OnSectionDeActivated()
    {
      DirecTV_SHEF.ReceiverAddress = this.ReceiverAddress;
      DirecTV_SHEF.SaveSettings();
      base.OnSectionDeActivated();
      Log.Info("DirecTV SHEF: Configuration deactivated");
    }

    public override void OnSectionActivated()
    {
      DirecTV_SHEF.LoadSettings();
      this.ReceiverAddress = DirecTV_SHEF.ReceiverAddress;
      base.OnSectionActivated();
      Log.Info("DirecTV SHEF: Configuration activated for DirecTV receiver at " + this.ReceiverAddress);
    }

    #endregion SetupTv.SectionSettings

    private void buttonTest_Click(object sender, EventArgs e)
    {
      string address = tbAddress.Text.Trim();

      if (address.Length == 0)
      {
        MessageBox.Show(
          this,
          "You must specify the address of the DirecTV Receiver",
          "Missing address",
          MessageBoxButtons.OK,
          MessageBoxIcon.Exclamation);

        return;
      }

      try
      {
        HttpWebRequest req = (HttpWebRequest)HttpWebRequest.Create("http://" + address + ":8080/remote/processKey?key=poweron");
        StreamReader reader = new StreamReader(req.GetResponse().GetResponseStream());
        reader.ReadToEnd();

        MessageBox.Show(
          this,
          "Your DirecTV receiver should have turned on",
          "DirecTV receiver communication ok",
          MessageBoxButtons.OK,
          MessageBoxIcon.Information);
      }
      catch (Exception ex)
      {
        Log.Error("DirecTV_SHEF - Config Test: {0}", ex.Message);

        MessageBox.Show(
          this,
          "Could not successfully communicate with your DirecTV receiver:\n\n" + ex.Message,
          "DirecTV receiver communication failed",
          MessageBoxButtons.OK,
          MessageBoxIcon.Error);
      }
    }
  }
}